﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using Steema.TeeChart.Tools;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 최근접 포인트
        /// </summary>
        private NearestPoint nearestPoint;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.styleComboBox.DropDownStyle = ComboBoxStyle.DropDownList;

            this.styleComboBox.Items.Add("None"     );
            this.styleComboBox.Items.Add("Circle"   );
            this.styleComboBox.Items.Add("Rectangle");
            this.styleComboBox.Items.Add("Diamond"  );

            this.styleComboBox.SelectedIndex = 1;

            Text = "NearestPoint 클래스 : 최근접 포인트 구하기";

            this.activeCheckBox.Checked = true;

            this.drawLineCheckBox.Checked = true;

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            Points points = new Points(this.tChart.Chart);

            points.FillSampleValues(10);

            this.nearestPoint = new NearestPoint(this.tChart.Chart);

            this.nearestPoint.Size        = 10;
            this.nearestPoint.Brush.Color = Color.Red;
            this.nearestPoint.Pen.Color   = Color.Red;
            this.nearestPoint.Pen.Width   = 2;
            this.nearestPoint.Series      = points;

            this.styleComboBox.SelectedIndexChanged += styleComboBox_SelectedIndexChanged;
            this.activeCheckBox.CheckedChanged      += activeCheckBox_CheckedChanged;
            this.drawLineCheckBox.CheckedChanged    += drawLineCheckBox_CheckedChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 스타일 콤보 박스 선택 인덱스 변경시 처리하기 - styleComboBox_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 스타일 콤보 박스 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void styleComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.nearestPoint.Style = (NearestPointStyles)this.styleComboBox.SelectedIndex;
        }

        #endregion
        #region 활성화 체크 박스 체크 변경시 처리하기 - activeCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 활성화 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void activeCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.nearestPoint.Active = this.activeCheckBox.Checked;
        }

        #endregion
        #region 라인 그리기 체크 박스 체크 변경시 처리하기 - drawLineCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 라인 그리기 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void drawLineCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.nearestPoint.DrawLine = this.drawLineCheckBox.Checked;
        }

        #endregion
    }
}